==> zio-aws-omics_2.12-5.20.22.1-sources.jar: zio/aws/omics/model/GetReferenceImportJobResponse.scala <==
package zio.aws.omics.model
import zio.aws.omics.model.primitives.{
  RoleArn,
  SyntheticTimestamp_date_time,
  JobStatusMessage,
  ImportJobId,
  ReferenceStoreId
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class GetReferenceImportJobResponse(
    completionTime: Optional[SyntheticTimestamp_date_time] = Optional.Absent,
    creationTime: SyntheticTimestamp_date_time,
    id: ImportJobId,
    referenceStoreId: ReferenceStoreId,
    roleArn: RoleArn,
    sources: Iterable[zio.aws.omics.model.ImportReferenceSourceItem],
    status: zio.aws.omics.model.ReferenceImportJobStatus,
    statusMessage: Optional[JobStatusMessage] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse = {
    import GetReferenceImportJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
      .builder()
      .optionallyWith(
        completionTime.map(value =>
          SyntheticTimestamp_date_time.unwrap(value): Instant
        )
      )(_.completionTime)
      .creationTime(SyntheticTimestamp_date_time.unwrap(creationTime): Instant)
      .id(ImportJobId.unwrap(id): java.lang.String)
      .referenceStoreId(
        ReferenceStoreId.unwrap(referenceStoreId): java.lang.String
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .sources(sources.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .status(status.unwrap)
      .optionallyWith(
        statusMessage.map(value =>
          JobStatusMessage.unwrap(value): java.lang.String
        )
      )(_.statusMessage)
      .build()
  }
  def asReadOnly: zio.aws.omics.model.GetReferenceImportJobResponse.ReadOnly =
    zio.aws.omics.model.GetReferenceImportJobResponse.wrap(buildAwsValue())
}
object GetReferenceImportJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.omics.model.GetReferenceImportJobResponse =
      zio.aws.omics.model.GetReferenceImportJobResponse(
        completionTime.map(value => value),
        creationTime,
        id,
        referenceStoreId,
        roleArn,
        sources.map { item =>
          item.asEditable
        },
        status,
        statusMessage.map(value => value)
      )
    def completionTime: Optional[SyntheticTimestamp_date_time]
    def creationTime: SyntheticTimestamp_date_time
    def id: ImportJobId
    def referenceStoreId: ReferenceStoreId
    def roleArn: RoleArn
    def sources: List[zio.aws.omics.model.ImportReferenceSourceItem.ReadOnly]
    def status: zio.aws.omics.model.ReferenceImportJobStatus
    def statusMessage: Optional[JobStatusMessage]
    def getCompletionTime: ZIO[Any, AwsError, SyntheticTimestamp_date_time] =
      AwsError.unwrapOptionField("completionTime", completionTime)
    def getCreationTime: ZIO[Any, Nothing, SyntheticTimestamp_date_time] =
      ZIO.succeed(creationTime)
    def getId: ZIO[Any, Nothing, ImportJobId] = ZIO.succeed(id)
    def getReferenceStoreId: ZIO[Any, Nothing, ReferenceStoreId] =
      ZIO.succeed(referenceStoreId)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getSources: ZIO[Any, Nothing, List[
      zio.aws.omics.model.ImportReferenceSourceItem.ReadOnly
    ]] = ZIO.succeed(sources)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.omics.model.ReferenceImportJobStatus] =
      ZIO.succeed(status)
    def getStatusMessage: ZIO[Any, AwsError, JobStatusMessage] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
  ) extends zio.aws.omics.model.GetReferenceImportJobResponse.ReadOnly {
    override val completionTime: Optional[SyntheticTimestamp_date_time] =
      zio.aws.core.internal
        .optionalFromNullable(impl.completionTime())
        .map(value =>
          zio.aws.omics.model.primitives.SyntheticTimestamp_date_time(value)
        )
    override val creationTime: SyntheticTimestamp_date_time =
      zio.aws.omics.model.primitives
        .SyntheticTimestamp_date_time(impl.creationTime())
    override val id: ImportJobId =
      zio.aws.omics.model.primitives.ImportJobId(impl.id())
    override val referenceStoreId: ReferenceStoreId =
      zio.aws.omics.model.primitives.ReferenceStoreId(impl.referenceStoreId())
    override val roleArn: RoleArn =
      zio.aws.omics.model.primitives.RoleArn(impl.roleArn())
    override val sources
        : List[zio.aws.omics.model.ImportReferenceSourceItem.ReadOnly] = impl
      .sources()
      .asScala
      .map { item =>
        zio.aws.omics.model.ImportReferenceSourceItem.wrap(item)
      }
      .toList
    override val status: zio.aws.omics.model.ReferenceImportJobStatus =
      zio.aws.omics.model.ReferenceImportJobStatus.wrap(impl.status())
    override val statusMessage: Optional[JobStatusMessage] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statusMessage())
        .map(value => zio.aws.omics.model.primitives.JobStatusMessage(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
  ): zio.aws.omics.model.GetReferenceImportJobResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-omics_2.12-6.20.74.1-sources.jar: zio/aws/omics/model/GetReferenceImportJobResponse.scala <==
package zio.aws.omics.model
import zio.aws.omics.model.primitives.{
  RoleArn,
  SyntheticTimestamp_date_time,
  JobStatusMessage,
  ImportJobId,
  ReferenceStoreId
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class GetReferenceImportJobResponse(
    id: ImportJobId,
    referenceStoreId: ReferenceStoreId,
    roleArn: RoleArn,
    status: zio.aws.omics.model.ReferenceImportJobStatus,
    statusMessage: Optional[JobStatusMessage] = Optional.Absent,
    creationTime: SyntheticTimestamp_date_time,
    completionTime: Optional[SyntheticTimestamp_date_time] = Optional.Absent,
    sources: Iterable[zio.aws.omics.model.ImportReferenceSourceItem]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse = {
    import GetReferenceImportJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
      .builder()
      .id(ImportJobId.unwrap(id): java.lang.String)
      .referenceStoreId(
        ReferenceStoreId.unwrap(referenceStoreId): java.lang.String
      )
      .roleArn(RoleArn.unwrap(roleArn): java.lang.String)
      .status(status.unwrap)
      .optionallyWith(
        statusMessage.map(value =>
          JobStatusMessage.unwrap(value): java.lang.String
        )
      )(_.statusMessage)
      .creationTime(SyntheticTimestamp_date_time.unwrap(creationTime): Instant)
      .optionallyWith(
        completionTime.map(value =>
          SyntheticTimestamp_date_time.unwrap(value): Instant
        )
      )(_.completionTime)
      .sources(sources.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.omics.model.GetReferenceImportJobResponse.ReadOnly =
    zio.aws.omics.model.GetReferenceImportJobResponse.wrap(buildAwsValue())
}
object GetReferenceImportJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.omics.model.GetReferenceImportJobResponse =
      zio.aws.omics.model.GetReferenceImportJobResponse(
        id,
        referenceStoreId,
        roleArn,
        status,
        statusMessage.map(value => value),
        creationTime,
        completionTime.map(value => value),
        sources.map { item =>
          item.asEditable
        }
      )
    def id: ImportJobId
    def referenceStoreId: ReferenceStoreId
    def roleArn: RoleArn
    def status: zio.aws.omics.model.ReferenceImportJobStatus
    def statusMessage: Optional[JobStatusMessage]
    def creationTime: SyntheticTimestamp_date_time
    def completionTime: Optional[SyntheticTimestamp_date_time]
    def sources: List[zio.aws.omics.model.ImportReferenceSourceItem.ReadOnly]
    def getId: ZIO[Any, Nothing, ImportJobId] = ZIO.succeed(id)
    def getReferenceStoreId: ZIO[Any, Nothing, ReferenceStoreId] =
      ZIO.succeed(referenceStoreId)
    def getRoleArn: ZIO[Any, Nothing, RoleArn] = ZIO.succeed(roleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.omics.model.ReferenceImportJobStatus] =
      ZIO.succeed(status)
    def getStatusMessage: ZIO[Any, AwsError, JobStatusMessage] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
    def getCreationTime: ZIO[Any, Nothing, SyntheticTimestamp_date_time] =
      ZIO.succeed(creationTime)
    def getCompletionTime: ZIO[Any, AwsError, SyntheticTimestamp_date_time] =
      AwsError.unwrapOptionField("completionTime", completionTime)
    def getSources: ZIO[Any, Nothing, List[
      zio.aws.omics.model.ImportReferenceSourceItem.ReadOnly
    ]] = ZIO.succeed(sources)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
  ) extends zio.aws.omics.model.GetReferenceImportJobResponse.ReadOnly {
    override val id: ImportJobId =
      zio.aws.omics.model.primitives.ImportJobId(impl.id())
    override val referenceStoreId: ReferenceStoreId =
      zio.aws.omics.model.primitives.ReferenceStoreId(impl.referenceStoreId())
    override val roleArn: RoleArn =
      zio.aws.omics.model.primitives.RoleArn(impl.roleArn())
    override val status: zio.aws.omics.model.ReferenceImportJobStatus =
      zio.aws.omics.model.ReferenceImportJobStatus.wrap(impl.status())
    override val statusMessage: Optional[JobStatusMessage] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statusMessage())
        .map(value => zio.aws.omics.model.primitives.JobStatusMessage(value))
    override val creationTime: SyntheticTimestamp_date_time =
      zio.aws.omics.model.primitives
        .SyntheticTimestamp_date_time(impl.creationTime())
    override val completionTime: Optional[SyntheticTimestamp_date_time] =
      zio.aws.core.internal
        .optionalFromNullable(impl.completionTime())
        .map(value =>
          zio.aws.omics.model.primitives.SyntheticTimestamp_date_time(value)
        )
    override val sources
        : List[zio.aws.omics.model.ImportReferenceSourceItem.ReadOnly] = impl
      .sources()
      .asScala
      .map { item =>
        zio.aws.omics.model.ImportReferenceSourceItem.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.omics.model.GetReferenceImportJobResponse
  ): zio.aws.omics.model.GetReferenceImportJobResponse.ReadOnly = new Wrapper(
    impl
  )
}
